@@ -61,6 +61,8 @@ PrintPreview.isRunning = function() {
  */
 PrintPreview.start = function(initialAction, instance) {
     var di = EAction.getDocumentInterface();
+    var doc = di.getDocument();
+
     var a = di.getDefaultAction();
     a.finishEvent();
     if (isNull(instance)) {
@@ -72,12 +74,76 @@ PrintPreview.start = function(initialAction, instance) {
     if (!isNull(initialAction)) {
         PrintPreview.instance.initialAction = initialAction;
     }
+
+    // auto setup:
+    var appWin = RMainWindowQt.getMainWindow();
+    var buttons = makeQMessageBoxStandardButtons(QMessageBox.Yes, QMessageBox.No);
+
+    var paperSizeMM = Print.getPaperSizeMM(doc);
+    var paperSizeName = Print.getPaperSizeNameFromSize(paperSizeMM);
+    var paperSizeAccepted = doc.getVariable("PageSettings/PaperSizeAccepted");
+
+    if (paperSizeName==="" && paperSizeAccepted!==true) {
+        // custom paper size:
+        // ask user to adjust to default paper size:
+        var defaultPaperSizeName = Print.getDefaultPaperSizeName(doc);
+        var ret = QMessageBox.warning(
+            appWin,
+            qsTr("Auto Paper Size"),
+            qsTr("The paper size is set to a custom size (%1x%2mm). Do you want to change it to the default paper size of your printer (%3)?").arg(paperSizeMM.width()).arg(paperSizeMM.height()).arg(defaultPaperSizeName),
+            buttons
+        );
+        if (ret===QMessageBox.Yes) {
+            var paperUnit = Print.getPaperUnit(doc);
+            var defPaperSize = Print.getDefaultPaperSizeMM();
+            var w = RUnit.convert(defPaperSize.width(), RS.Millimeter, paperUnit);
+            doc.setVariable("PageSettings/PaperWidth", w);
+            var h = RUnit.convert(defPaperSize.height(), RS.Millimeter, paperUnit);
+            doc.setVariable("PageSettings/PaperHeight", h);
+            doc.setVariable("MultiPageSettings/Columns", 1);
+            doc.setVariable("MultiPageSettings/Rows", 1);
+
+            // 10mm margin:
+            var m = RUnit.convert(10, RS.Millimeter, paperUnit);
+            doc.setVariable("MultiPageSettings/GlueMarginsLeft", m);
+            doc.setVariable("MultiPageSettings/GlueMarginsTop", m);
+            doc.setVariable("MultiPageSettings/GlueMarginsRight", m);
+            doc.setVariable("MultiPageSettings/GlueMarginsBottom", m);
+        }
+        else {
+            // store information that paper size was accepted as is (don't show dialog again):
+            doc.setVariable("PageSettings/PaperSizeAccepted", true);
+        }
+    }
+
+    var bbPaper = Print.getPaperBox(doc);
+    bbPaper.growXY(bbPaper.getWidth()/100, bbPaper.getHeight()/100);
+    var bbDoc = doc.getBoundingBox();
+    var positionAccepted = doc.getVariable("PageSettings/PositionAccepted");
+    // check if paper contains drawing:
+    if (!bbPaper.containsBox(bbDoc) && !positionAccepted) {
+        var initialZoom = appWin.property("PrintPreview/InitialZoom");
+        if (initialZoom!=="View") {
+            var ret = QMessageBox.warning(appWin,
+                qsTr("Auto fit"),
+                qsTr("Auto fit drawing to paper?"),
+                buttons);
+            if (ret===QMessageBox.Yes) {
+                appWin.setProperty("PrintPreview/InitialZoom", "Auto");
+            }
+            else {
+                doc.setVariable("PageSettings/PositionAccepted", true);
+            }
+        }
+    }
+
     di.setDefaultAction(PrintPreview.instance);
 
     var ga = RGuiAction.getByScriptFile("scripts/File/PrintPreview/PrintPreview.js")
     if (!isNull(ga)) {
         ga.setChecked(true);
     }
+
 };
 
 /**
@@ -131,9 +197,14 @@ function PrintPreviewImpl(guiAction) {
 
     this.updateDisabled = false;
 
-    var bitmap = new QBitmap(PrintPreviewImpl.includeBasePath + "/PrintPreviewOffsetCursor.png", "PNG");
-    var mask = new QBitmap(PrintPreviewImpl.includeBasePath + "/PrintPreviewOffsetCursorMask.png", "PNG");
-    this.cursor = new QCursor(bitmap, mask, 15, 13);
+    if (RSettings.getBoolValue("GraphicsView/SystemCursors", false)===true) {
+        this.cursor = new QCursor(Qt.OpenHandCursor);
+    }
+    else {
+        var bitmap = new QBitmap(PrintPreviewImpl.includeBasePath + "/PrintPreviewOffsetCursor.png", "PNG");
+        var mask = new QBitmap(PrintPreviewImpl.includeBasePath + "/PrintPreviewOffsetCursorMask.png", "PNG");
+        this.cursor = new QCursor(bitmap, mask, 15, 13);
+    }
     this.view = undefined;
     this.saveView = false;
     this.savedScale = undefined;
@@ -152,6 +223,7 @@ PrintPreviewImpl.State = {
 };
 
 PrintPreviewImpl.prototype.beginEvent = function() {
+    qDebug("PrintPreviewImpl.prototype.beginEvent");
     var di = this.getDocumentInterface();
 
     var appWin = RMainWindowQt.getMainWindow();
@@ -176,7 +248,9 @@ PrintPreviewImpl.prototype.beginEvent = function() {
     var mdiChild = EAction.getMdiChild();
     this.view = mdiChild.getLastKnownViewWithFocus();
 
+    di.disableUpdates();
     this.parentClass.prototype.beginEvent.call(this);
+    di.enableUpdates();
 
     if (!isNull(this.view)) {
         var document = this.getDocument();
@@ -193,7 +267,7 @@ PrintPreviewImpl.prototype.beginEvent = function() {
             }
         }
 
-        // needed to update pattern scaling according to drawing scale:
+        // needed to update linetype pattern scaling according to drawing scale:
         di.regenerateScenes();
     }
 
@@ -201,7 +275,8 @@ PrintPreviewImpl.prototype.beginEvent = function() {
     action.triggered.connect(this, "updateBackgroundDecoration");
 
     if (initialZoom==="Auto") {
-        this.slotAutoFitDrawing();
+        // auto fit drawing and auto set orientation:
+        this.slotAutoFitDrawing(true);
     }
     else if (initialZoom==="View") {
         Print.setColumns(di, 1);
@@ -395,8 +470,12 @@ PrintPreviewImpl.prototype.showUiOptions = function(resume) {
     var widgets = getWidgets(optionsToolBar);
 
     var document = this.getDocument();
+    var di = this.getDocumentInterface();
     var scaleString = Print.getScaleString(document);
 
+    var mod = document.isModified();
+
+    // note: this modifies the document:
     this.initScaleCombo();
 
     // update option toolbar widgets
@@ -411,7 +490,9 @@ PrintPreviewImpl.prototype.showUiOptions = function(resume) {
     var scaleCombo = widgets["Scale"];
     scaleCombo.blockSignals(true);
     scaleCombo.setEditText(scaleString);
+    di.disableUpdates();
     this.slotScaleChanged(scaleString);
+    di.enableUpdates();
     scaleCombo.blockSignals(false);
 
     var action = RGuiAction.getByScriptFile("scripts/Edit/DrawingPreferences/DrawingPreferences.js");
@@ -452,6 +533,9 @@ PrintPreviewImpl.prototype.showUiOptions = function(resume) {
     }
     widgets["Landscape"].blockSignals(false);
     widgets["Portrait"].blockSignals(false);
+
+    // workaround for FS#2356 - File > Close: Closing dialog stays open after clicking Save
+    document.setModified(mod);
 };
 
 /**
@@ -462,15 +546,23 @@ PrintPreviewImpl.prototype.initUiOptions = function(resume, optionsToolBar) {
 };
 
 PrintPreviewImpl.prototype.initScaleCombo = function() {
+    var document = this.getDocument();
+    if (isNull(document)) {
+        return;
+    }
+
     var optionsToolBar = EAction.getOptionsToolBar();
     var scaleCombo = optionsToolBar.findChild("Scale");
     scaleCombo.blockSignals(true);
     var prev = scaleCombo.currentText;
     scaleCombo.clear();
-    var scales = this.getScales();
-    for (var i=0; i<scales.length; ++i) {
-        scaleCombo.addItem(scales[i]);
-    }
+
+    scaleCombo.setScale(true, document.getUnit())
+
+//    var scales = this.getScales();
+//    for (var i=0; i<scales.length; ++i) {
+//        scaleCombo.addItem(scales[i]);
+//    }
     scaleCombo.setEditText(prev);
     scaleCombo.blockSignals(false);
 };
@@ -526,7 +618,7 @@ PrintPreviewImpl.prototype.updateBackgroundDecoration = function() {
     path.setPen(new QPen(Qt.NoPen));
     path.setBrush(new QBrush(new QColor(colBg)));
     path.addRect(new QRectF(-1.0e8, -1.0e8, 2.0e8, 2.0e8));
-    this.view.addToBackground(path);
+    this.view.addToBackground(RGraphicsSceneDrawable.createFromPainterPath(path));
 
     // page border with shadow
     if (Print.getShowPaperBorders(document)) {
@@ -536,7 +628,7 @@ PrintPreviewImpl.prototype.updateBackgroundDecoration = function() {
             path.setPen(new QPen(Qt.NoPen));
             path.setBrush(new QBrush(new QColor(colShadow)));
             this.drawShadow(path, pages[i]);
-            this.view.addToBackground(path);
+            this.view.addToBackground(RGraphicsSceneDrawable.createFromPainterPath(path));
         }
 
         // paper background
@@ -547,7 +639,7 @@ PrintPreviewImpl.prototype.updateBackgroundDecoration = function() {
                     backgroundColor.blue());
             path.setBrush(new QBrush(color));
             this.drawPaper(path, pages[i]);
-            this.view.addToBackground(path);
+            this.view.addToBackground(RGraphicsSceneDrawable.createFromPainterPath(path));
         }
 
         // paper border
@@ -556,7 +648,7 @@ PrintPreviewImpl.prototype.updateBackgroundDecoration = function() {
             path.setPen(new QPen(new QColor(colBorder)));
             path.setBrush(new QBrush(Qt.NoBrush));
             this.drawPaper(path, pages[i]);
-            this.view.addToBackground(path);
+            this.view.addToBackground(RGraphicsSceneDrawable.createFromPainterPath(path));
         }
     }
 
@@ -578,17 +670,17 @@ PrintPreviewImpl.prototype.updateBackgroundDecoration = function() {
     for (i = 0; i < pages.length; ++i) {
         this.drawGlueMargins(path, pages[i]);
     }
-    this.view.addToBackground(path);
+    this.view.addToBackground(RGraphicsSceneDrawable.createFromPainterPath(path));
 
-    // TODO: hook for page tags
+    // hook for page tags, footer, etc.:
     this.addDecorations(pages);
 
-    // crop marks
+    // crop marks:
     if (Print.getPrintCropMarks(document)) {
         for ( i = 0; i < pages.length; ++i) {
             path = new RPainterPath();
             Print.drawCropMarks(document, path, pages[i], false);
-            this.view.addToBackground(path);
+            this.view.addToBackground(RGraphicsSceneDrawable.createFromPainterPath(path));
         }
     }
 
@@ -739,7 +831,7 @@ PrintPreviewImpl.prototype.slotScaleChanged = function(scaleString) {
 
     this.updateBackgroundTransform();
 
-    // update pattern scale accordint to drawing scale:
+    // update pattern scale according to drawing scale:
     di.regenerateScenes();
 };
 
@@ -889,10 +981,10 @@ PrintPreviewImpl.prototype.slotAutoFitBox = function(box) {
 /**
  * Auto fit drawing button clicked in options toolbar.
  */
-PrintPreviewImpl.prototype.slotAutoFitDrawing = function() {
+PrintPreviewImpl.prototype.slotAutoFitDrawing = function(ori) {
     var di = this.getDocumentInterface();
     var document = di.getDocument();
-    Print.autoFitDrawing(di);
+    Print.autoFitDrawing(di, ori);
     PrintPreviewImpl.updateScaleString(document);
 
     // needed to update pattern scaling according to drawing scale:
