@@ -53,7 +53,7 @@ Transform.prototype.verifySelection = function() {
 };
 
 /**
- * Implemetation of getOperation for tools that operate on a selection and
+ * Implementation of getOperation for tools that operate on a selection and
  * do something with every entity in the selection (e.g. move, rotate, ...).
  * The callback function 'this.transform(entity, copy number)' is called for
  * every selected entity.
@@ -117,6 +117,10 @@ Transform.prototype.getOperation = function(preview, selectResult, cache) {
                 break;
             }
 
+//            if (i%1000===0) {
+//                qDebug("progress: %1%".arg(i/ids.length*100));
+//            }
+
             id = ids[i];
             entityP = document.queryEntity(id);
             if (isNull(entityP)) {
@@ -125,8 +129,8 @@ Transform.prototype.getOperation = function(preview, selectResult, cache) {
             //qDebug("%1 / %2".arg(i).arg(ids.length-1));
 
             // entity is valid as long as entityP is valid:
-            entity = entityP.data();
-            //entity = entityP.clone();
+            //entity = entityP.data();
+            entity = entityP.clone();
 
             // copy: assign new IDs
             if (copies>0) {
@@ -135,9 +139,9 @@ Transform.prototype.getOperation = function(preview, selectResult, cache) {
                 }
             }
 
-            var f = RAddObjectsOperation.GeometryOnly;
+            var f = RAddObjectsOperation.NoFlags;
             if (!this.useCurrentAttributes) {
-                f = f | RAddObjectsOperation.UseAttributes;
+                f = RAddObjectsOperation.UseAttributes | RAddObjectsOperation.GeometryOnly;
             }
 
             if (cache) {
