@@ -890,7 +890,12 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
                 }
             }
             if (!isNull(value)) {
-                c.value = value;
+                if (isOfType(c, QSpinBox)) {
+                    c.value = parseInt(value);
+                }
+                else {
+                    c.value = parseFloat(value);
+                }
             }
             continue;
         }
@@ -1063,7 +1068,7 @@ WidgetFactory.connect = function(sig, signalReceiver, objectName, isValue) {
 
     //if (eval("signalReceiver." + slot) != undefined) {
     if (!isNull(signalReceiver[slot])) {
-        if (RSettings.getQtVersion() > 0x060000) {
+        if (RSettings.getQtVersion() >= 0x060000) {
             sig.connect(signalReceiver, signalReceiver[slot]);
         }
         else {
@@ -1087,7 +1092,11 @@ WidgetFactory.moveChildren = function(sourceWidget, targetWidget, settingsGroup)
     // on this (especially on macOS):
     var children = sourceWidget.children();
     for(var i=0;i<children.length;++i) {
-        var w=children[i];
+        var w = children[i];
+        if (isNull(w)) {
+            continue;
+        }
+
         w.setProperty("SettingsGroup", settingsGroup);
 
         // add separator:
@@ -1143,7 +1152,7 @@ WidgetFactory.moveChildren = function(sourceWidget, targetWidget, settingsGroup)
 };
 
 WidgetFactory.adjustIcons = function(includeBasePath, widget) {
-    if (!isFunction(widget.children)) {
+    if (isNull(widget) || !isFunction(widget.children)) {
         return;
     }
 
