@@ -17,6 +17,8 @@
  * along with QCAD.
  */
 
+include("scripts/Widgets/Widgets.js");
+
 /**
  * Represents a panel in the tool matrix. Panels are embedded as child items under
  * the root item of the appropriate category in the tool matrix tree.
@@ -62,7 +64,7 @@ RCadToolMatrixTreePanel.getPressedStyle = function() {
             + "  border-radius: 4px; "
             + "  background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #a4a4a4, stop: 0.8 #b3b3b3, stop: 1 #b5b5b5);"
             + "}";
-}
+};
 
 /**
  * Inserts actions added to the panel into the flow layout of the panel.
@@ -108,7 +110,6 @@ RCadToolMatrixTreePanel.prototype.actionEvent = function(event) {
     }
 };
 
-
 /**
  * CAD tool matrix tree widget.
  */
@@ -131,12 +132,21 @@ function RCadToolMatrixTree(parent) {
         this.header().setResizeMode(0, QHeaderView.Stretch);
     }
 
-    this.setItemDelegate(new RToolMatrixItemDelegate(this, this));
+    if (!RSettings.isQt(6)) {
+        // TODO Qt6
+        this.setItemDelegate(new RToolMatrixItemDelegate(this, this));
+    }
 
-    this.itemPressed.connect(this, "handleItemPress");
+    //this.itemPressed.connect(this, "handleItemPress");
+    this.itemPressed.connect(this, RCadToolMatrixTree.prototype.handleItemPress);
 
     this.minimumWidth = 120;
-    this.sizeIncrement = new QSize(32,0);
+    if (RSettings.getQtVersion()>0x060000) {
+        this.setSizeIncrement(new QSize(32,0));
+    }
+    else {
+        this.sizeIncrement = new QSize(32,0);
+    }
 
     var p = this.palette;
     p.setColor(QPalette.Base, new QColor("#dddddd"));
@@ -168,7 +178,7 @@ RCadToolMatrixTree.prototype.updatePanelSizes = function() {
         embeddedWidget.setFixedHeight(height);
         subItem.setSizeHint(0, new QSize(width, height));
     }
-    this.updateGeometries();
+    //this.updateGeometries();
 };
 
 /**
@@ -284,6 +294,10 @@ RCadToolMatrixTree.prototype.filter = function(text) {
                 continue;
             }
 
+            if (!isFunction(child.defaultAction)) {
+                continue;
+            }
+
             var action = child.defaultAction();
             if (isNull(action)) {
                 continue;
@@ -411,8 +425,6 @@ RCadToolMatrixTree.prototype.setListViewMode = function(enable) {
     RCadToolMatrixTree.prototype.updatePanelSizes.call(this);
 };
 
-
-
 function CadToolMatrix(guiAction) {
     Widgets.call(this, guiAction);
 }
@@ -459,11 +471,17 @@ CadToolMatrix.getToolMatrix = function() {
         // add tool matrix:
         toolMatrix = new RCadToolMatrixTree(appWin);
         toolMatrix.objectName = "ToolMatrix";
-        layout.addWidget(toolMatrix, 1, 0);
+        if (RSettings.getQtVersion()>0x060000) {
+            layout.addWidget(toolMatrix);
+        }
+        else {
+            layout.addWidget(toolMatrix, 1, 0);
+        }
 
         // init filter widget:
         var filterEdit = formWidget.findChild("FilterEdit");
-        filterEdit.textChanged.connect(toolMatrix, "filter");
+        //filterEdit.textChanged.connect(toolMatrix, "filter");
+        filterEdit.textChanged.connect(toolMatrix, toolMatrix.filter);
         var clearButton = formWidget.findChild("Clear");
         if (filterEdit.clearButtonEnabled===true) {
             clearButton.hide();
@@ -500,7 +518,7 @@ CadToolMatrix.getToolMatrixPanel = function(title, objectName, order) {
     var tm = CadToolMatrix.getToolMatrix();
 
     // find existing root item:
-    var flags = new Qt.MatchFlags(Qt.MatchFixedString | Qt.MatchRecursive);
+    var flags = makeQtMatchFlags(Qt.MatchFixedString, Qt.MatchRecursive);
     var items = tm.findItems(title, flags);
     var item;
     if (items.length===0) {
@@ -599,5 +617,9 @@ CadToolMatrix.uninit = function() {
         }
     }
     RSettings.setValue("CadToolMatrix/ClosedCategories", closedCategories.join(","));
-    RSettings.setValue("CadToolMatrix/ListViewMode", toolMatrix.listViewMode);
+
+    // TODO #qt6:
+    if (RSettings.getQtVersion()<0x060000) {
+        RSettings.setValue("CadToolMatrix/ListViewMode", toolMatrix.listViewMode);
+    }
 };
