@@ -40,7 +40,7 @@ CommandLine.prototype.beginEvent = function() {
 
     var appWin = RMainWindowQt.getMainWindow();
     var dock = appWin.findChild("CommandLineDock");
-    if (!QCoreApplication.arguments().contains("-no-show")) {
+    if (!RSettings.getOriginalArguments().contains("-no-show")) {
         dock.visible = !dock.visible;
         if (dock.visible) dock.raise();
     }
@@ -229,7 +229,7 @@ CommandLine.init = function(basePath) {
         di.repaintViews();
         di.setCursorPosition(sp);
     });
-    
+
     // user pressed enter, enter command or coordinate:
     leCommand.commandConfirmed.connect(function(command) {
         // enter with empty input: repeat last command:
@@ -299,7 +299,7 @@ CommandLine.init = function(basePath) {
                 if (!pos.isValid()) {
                     appWin.handleUserWarning(
                         qsTr("Invalid coordinate or distance \"%1\".")
-                            .arg(Qt.escape(cmd))
+                            .arg(RS.escape(cmd))
                     );
                     return;
                 }
@@ -392,12 +392,12 @@ CommandLine.init = function(basePath) {
         }
     });
     
-    leCommand.clearHistory.connect(teHistory, "clear");
+    leCommand.clearHistory.connect(function() { teHistory.clear(); });
 
     // show message to user:
     appWin.userMessage.connect(function(message, escape) {
         if (escape) {
-            message = Qt.escape(message);
+            message = RS.escape(message);
         }
 
         appendAndScroll("<span>" + message + "</span>");
@@ -411,7 +411,7 @@ CommandLine.init = function(basePath) {
         }
 
         if (escape) {
-            message = Qt.escape(message);
+            message = RS.escape(message);
             // workaround for Qt showing &quot; in label:
             message = message.replace(/&quot;/g, "\"");
         }
@@ -425,7 +425,7 @@ CommandLine.init = function(basePath) {
     // show info to user:
     appWin.userInfo.connect(function(message, escape) {
         if (escape) {
-            message = Qt.escape(message);
+            message = RS.escape(message);
         }
 
         appendAndScroll("<span style='color:" + infoBlue + ";'>" + message + "</span>");
@@ -443,7 +443,7 @@ CommandLine.init = function(basePath) {
 
         var msgEsc = message;
         if (escape) {
-            msgEsc = Qt.escape(message);
+            msgEsc = RS.escape(message);
         }
 
         var cartCoordSep = RSettings.getStringValue("Input/CartesianCoordinateSeparator", ',');
