@@ -19,7 +19,7 @@
 
 include("scripts/EAction.js");
 include("scripts/sprintf.js");
-include("../../WidgetFactory.js");
+include("scripts/WidgetFactory.js");
 
 /**
  * Internal helper class. Notified when properties are changed.
@@ -40,9 +40,12 @@ PropertyWatcher.prototype.propertyChanged = function(value) {
     // only do something if the value has actually changed
     // remember edited status of widgets
 
+//    qDebug("propertyChanged:", value);
+//    qDebug("propertyChanged: sender: ", this.sender);
+
     var attributes = this.propertyEditor.getPropertyAttributes(this.propertyType);
 
-    var typeHint = 0;
+    var typeHint = RS.UnknownType;
 
     // value is a list property (e.g. x coordinate of a vertex of a polyline):
     if (attributes.isList()) {
@@ -60,7 +63,6 @@ PropertyWatcher.prototype.propertyChanged = function(value) {
 
     // value comes from a combo box:
     else if (isComboBox(this.sender)) {
-
         // value is index of combo box:
         if (isNumber(value)) {
             if (this.sender.itemData(value)===PropertyEditor.varies) {
@@ -96,7 +98,20 @@ PropertyWatcher.prototype.propertyChanged = function(value) {
             return;
         }
         if (this.sender.isInteger()) {
-            typeHint = 2;
+            typeHint = RS.Int;
+        }
+    }
+
+    // value is number from a math combo box:
+    else if (this.sender.toString().startsWith("RMathComboBox")) {
+        if (this.sender.currentText===this.sender.originalText) {
+            return;
+        }
+        this.sender.setProperty("originalText", this.sender.text);
+        value = this.sender.getValue();
+        if (isNaN(value)) {
+            this.propertyEditor.updateGui(true);
+            return;
         }
     }
 
@@ -186,6 +201,11 @@ IndexWatcher.prototype.indexChanged = function(index) {
 function PropertyEditorImpl(basePath) {
     RPropertyEditor.call(this);
 
+    if (isNull(basePath)) {
+        // only used to initialize prototype for derived class:
+        return;
+    }
+
     this.setEntityTypeFilter(RS.EntityAll);
     this.widget = WidgetFactory.createWidget(basePath, "PropertyEditor.ui");
     this.basePath = basePath;
@@ -202,36 +222,61 @@ function PropertyEditorImpl(basePath) {
     this.widget.findChild("LabelProtected").text = RSettings.translate("REntity", "Protected") + this.colon;
 
     var selectionCombo = this.widget.findChild("Selection");
-    selectionCombo["activated(int)"].connect(this, "filterChanged");
+    selectionCombo["activated(int)"].connect(this, this.filterChanged);
     selectionCombo.installEventFilter(new REventFilter(QEvent.Wheel.valueOf(), true));
     selectionCombo.focusPolicy = Qt.ClickFocus;
 
     // initialize fixed general properties at the top:
     var layerCombo = this.widget.findChild("Layer");
-    layerCombo['activated(QString)'].connect(
-                new PropertyWatcher(this, layerCombo, REntity.PropertyLayer),
-                'propertyChanged');
+    if (RSettings.isQt(6)) {
+        var pw = new PropertyWatcher(this, layerCombo, REntity.PropertyLayer);
+        layerCombo.textActivated.connect(pw, pw.propertyChanged);
+    }
+    else {
+        layerCombo['activated(QString)'].connect(
+                    new PropertyWatcher(this, layerCombo, REntity.PropertyLayer),
+                    'propertyChanged');
+    }
+
     layerCombo.installEventFilter(new REventFilter(QEvent.Wheel.valueOf(), true));
     layerCombo.focusPolicy = Qt.ClickFocus;
 
     var colorCombo = this.widget.findChild("Color");
-    colorCombo['activated(int)'].connect(
-                new PropertyWatcher(this, colorCombo, REntity.PropertyColor),
-                'propertyChanged');
+    if (RSettings.isQt(6)) {
+        var pw = new PropertyWatcher(this, colorCombo, REntity.PropertyColor);
+        colorCombo['activated(int)'].connect(pw, pw.propertyChanged);
+    }
+    else {
+        colorCombo['activated(int)'].connect(
+                    new PropertyWatcher(this, colorCombo, REntity.PropertyColor),
+                    'propertyChanged');
+    }
     colorCombo.installEventFilter(new REventFilter(QEvent.Wheel.valueOf(), true));
     colorCombo.focusPolicy = Qt.ClickFocus;
 
     var lineweightCombo = this.widget.findChild("Lineweight");
-    lineweightCombo['activated(int)'].connect(
-                new PropertyWatcher(this, lineweightCombo, REntity.PropertyLineweight),
-                'propertyChanged');
+    if (RSettings.isQt(6)) {
+        var pw = new PropertyWatcher(this, lineweightCombo, REntity.PropertyLineweight);
+        lineweightCombo['activated(int)'].connect(pw, pw.propertyChanged);
+    }
+    else {
+        lineweightCombo['activated(int)'].connect(
+                    new PropertyWatcher(this, lineweightCombo, REntity.PropertyLineweight),
+                    'propertyChanged');
+    }
     lineweightCombo.installEventFilter(new REventFilter(QEvent.Wheel.valueOf(), true));
     lineweightCombo.focusPolicy = Qt.ClickFocus;
 
     var linetypeCombo = this.widget.findChild("Linetype");
-    linetypeCombo['activated(int)'].connect(
-                new PropertyWatcher(this, linetypeCombo, REntity.PropertyLinetype),
-                'propertyChanged');
+    if (RSettings.isQt(6)) {
+        var pw = new PropertyWatcher(this, linetypeCombo, REntity.PropertyLinetype);
+        linetypeCombo['activated(int)'].connect(pw, pw.propertyChanged);
+    }
+    else {
+        linetypeCombo['activated(int)'].connect(
+                    new PropertyWatcher(this, linetypeCombo, REntity.PropertyLinetype),
+                    'propertyChanged');
+    }
     linetypeCombo.installEventFilter(new REventFilter(QEvent.Wheel.valueOf(), true));
     linetypeCombo.focusPolicy = Qt.ClickFocus;
 
@@ -253,14 +298,27 @@ function PropertyEditorImpl(basePath) {
 
 
     var linetypeScaleEdit = this.widget.findChild("LinetypeScale");
-    linetypeScaleEdit.editingFinished.connect(
-                new PropertyWatcher(this, linetypeScaleEdit, REntity.PropertyLinetypeScale),
-                'propertyChanged');
+    if (RSettings.isQt(6)) {
+        var pw = new PropertyWatcher(this, linetypeScaleEdit, REntity.PropertyLinetypeScale);
+        linetypeScaleEdit.editingFinished.connect(pw, pw.propertyChanged);
+    }
+    else {
+        linetypeScaleEdit.editingFinished.connect(
+                    new PropertyWatcher(this, linetypeScaleEdit, REntity.PropertyLinetypeScale),
+                    'propertyChanged');
+    }
+
 
     var drawOrderEdit = this.widget.findChild("DrawOrder");
-    drawOrderEdit.editingFinished.connect(
-                new PropertyWatcher(this, drawOrderEdit, REntity.PropertyDrawOrder),
-                'propertyChanged');
+    if (RSettings.isQt(6)) {
+        var pw = new PropertyWatcher(this, drawOrderEdit, REntity.PropertyDrawOrder);
+        drawOrderEdit.editingFinished.connect(pw, pw.propertyChanged);
+    }
+    else {
+        drawOrderEdit.editingFinished.connect(
+                    new PropertyWatcher(this, drawOrderEdit, REntity.PropertyDrawOrder),
+                    'propertyChanged');
+    }
 
     this.geometryGroup = undefined;
     this.childGroup = undefined;
@@ -292,15 +350,15 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
     this.widget.updatesEnabled = false;
     if (!onlyChanges) {
         if (!isNull(this.geometryGroup)) {
-            this.geometryGroup.destroy();
+            destr(this.geometryGroup);
             this.geometryGroup = undefined;
         }
         if (!isNull(this.childGroup)) {
-            this.childGroup.destroy();
+            destr(this.childGroup);
             this.childGroup = undefined;
         }
         if (!isNull(this.customGroup)) {
-            this.customGroup.destroy();
+            destr(this.customGroup);
             this.customGroup = undefined;
         }
     }
@@ -362,20 +420,26 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
     if (!onlyChanges) {
         // create geometry group box with grid layout:
         this.geometryGroup = new QGroupBox(qsTr("Specific Properties"), this.widget);
+        this.geometryGroup.objectName = "GeometryGroup";
         layout.insertWidget(2, this.geometryGroup);
 
         // grid layout with three columns and N rows for N property controls:
         gridLayoutGeometry = new QGridLayout(this.geometryGroup);
         gridLayoutGeometry.setVerticalSpacing(2);
+        gridLayoutGeometry.setHorizontalSpacing(2);
+        // label:
         gridLayoutGeometry.setColumnStretch(0,0);
+        // control:
         gridLayoutGeometry.setColumnStretch(1,1);
-        gridLayoutGeometry.setColumnStretch(2,0);
+        // control or additional controls (e.g. clear button for dimension label):
+        gridLayoutGeometry.setColumnStretch(2,1);
         this.geometryGroup.setLayout(gridLayoutGeometry);
 
         // child properties
         // (block attributes shown when block reference is selected):
         // create child property group box with grid layout:
         this.childGroup = new QGroupBox(qsTr("Dependent Entities"), this.widget);
+        this.childGroup.objectName = "ChildGroup";
         layout.insertWidget(3, this.childGroup);
 
         // grid layout with four columns and N rows for N property controls:
@@ -393,6 +457,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
         if (RSettings.isXDataEnabled()) {
             // create custom property group box with grid layout:
             this.customGroup = new QGroupBox(qsTr("Custom"), this.widget);
+            //this.customGroup.objectName = "CustomGroup";
             layout.insertWidget(4, this.customGroup);
 
             // grid layout with four columns and N rows for N property controls:
@@ -427,11 +492,22 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
             var children = groupToClear.children();
             for (var i=0; i<children.length; i++) {
                 var child = children[i];
+                if (isNull(child)) {
+                    // don't destroy wrapper attached to the group box (QGroupBox_Wrapper):
+                    continue;
+                }
                 if (isOfType(child, QGridLayout)) {
                     // don't destroy layout:
                     continue;
                 }
-                children[i].destroy();
+
+                // qt 6: detect wrapper of QGroupBox and never delete that:
+                if (!isNull(child.wrappedType)) {
+                    continue;
+                }
+
+
+                destr(child);
             }
         }
     }
@@ -666,16 +742,15 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
                             group===RSettings.getAppId() && !attributes.isUndeletable()) {
 
                             var removeCustomPropertyButton = new QToolButton(this.widget);
-                            removeCustomPropertyButton.icon = new QIcon(this.basePath + "/RemoveCustomProperty.svg");
+                            removeCustomPropertyButton.icon = new QIcon(autoPath(this.basePath + "/RemoveCustomProperty.svg"));
                             removeCustomPropertyButton.iconSize = new QSize(12,12);
                             removeCustomPropertyButton.toolTip = qsTr("Remove this property from selected objects");
                             var name = propertyTypeId.getCustomPropertyName();
                             removeCustomPropertyButton.objectName = "DeleteCustomProperty" + name;
                             //qDebug("adding button to remove custom property named: ", name);
                             var propertyEditor = this;
-                            removeCustomPropertyButton.clicked.connect(
-                                        new PropertyWatcher(this, removeCustomPropertyButton, propertyTypeId),
-                                        'propertyRemoved');
+                            var pw = new PropertyWatcher(this, removeCustomPropertyButton, propertyTypeId);
+                            removeCustomPropertyButton.clicked.connect(pw, pw.propertyRemoved);
                             gridLayoutCustom.addWidget(removeCustomPropertyButton, row,3);
                         }
 
@@ -759,7 +834,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
     if (!isNull(gridLayoutCustom)) {
         if (RSettings.isXDataEnabled() && RSettings.getBoolValue("PropertyEditor/AddCustomProperties", true)!==false) {
             var addCustomPropertyButton = new QToolButton(this.widget);
-            addCustomPropertyButton.icon = new QIcon(this.basePath + "/AddCustomProperty.svg");
+            addCustomPropertyButton.icon = new QIcon(autoPath(this.basePath + "/AddCustomProperty.svg"));
             addCustomPropertyButton.iconSize = new QSize(12,12);
             addCustomPropertyButton.toolTip = qsTr("Add custom property to selected objects");
             addCustomPropertyButton.objectName = "AddCustomProperty";
@@ -808,7 +883,7 @@ PropertyEditorImpl.prototype.initControls = function(propertyTypeId, onlyChanges
         requestAllButton.objectName = objectName + "_request";
         requestAllButton.text = qsTr("Show");
         requestAllButton.toolTip = qsTr("Show all properties");
-        requestAllButton.clicked.connect(this, "requestAllProperties");
+        requestAllButton.clicked.connect(this, this.requestAllProperties);
         requestAllButton.setSizePolicy(QSizePolicy.Ignored, QSizePolicy.Preferred);
 
         return new Array(requestAllButton);
@@ -845,6 +920,23 @@ PropertyEditorImpl.prototype.initControls = function(propertyTypeId, onlyChanges
                     objectName, propertyTypeId, onlyChanges, control, false, true);
     }
 
+    // DIMLUNIT: combo box with DIMLUNIT choices:
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimlunit.getId() ||
+             propertyTypeId.getId()===RDimensionEntity.PropertyDimtad.getId() ||
+             //propertyTypeId.getId()===RDimensionEntity.PropertyDimdsep.getId() ||
+             propertyTypeId.getId()===RDimensionEntity.PropertyDimzin.getId() ||
+             propertyTypeId.getId()===RDimensionEntity.PropertyDimdec.getId() ||
+             propertyTypeId.getId()===RDimensionEntity.PropertyDimaunit.getId() ||
+             propertyTypeId.getId()===RDimensionEntity.PropertyDimazin.getId() ||
+             propertyTypeId.getId()===RDimensionEntity.PropertyDimadec.getId()) {
+        controls = this.initChoiceControls(
+                    objectName, propertyTypeId, onlyChanges, control, false, true);
+    }
+
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimdsep.getId()) {
+        controls = this.initStringControls(objectName, propertyTypeId, onlyChanges, control);
+        //controls[0].maxLength = 1;
+    }
 
     // Hatch pattern: combo box with hatch names:
     else if (propertyTypeId.getId()===RHatchEntity.PropertyPatternName.getId()) {
@@ -893,7 +985,8 @@ PropertyEditorImpl.prototype.initControls = function(propertyTypeId, onlyChanges
                 }
                 indexControl.setProperty('controlNames', a);
 
-                indexControl["valueChanged(int)"].connect(new IndexWatcher(this, indexControl, propertyTypeId), "indexChanged");
+                var iw = new IndexWatcher(this, indexControl, propertyTypeId)
+                indexControl["valueChanged(int)"].connect(iw, iw.indexChanged);
             }
             else {
                 // make sure that the values for the current list index are updated:
@@ -955,6 +1048,8 @@ PropertyEditorImpl.prototype.initControls = function(propertyTypeId, onlyChanges
  * \internal
  */
 PropertyEditorImpl.prototype.initNumberControls = function(objectName, propertyTypeId, onlyChanges, control, index) {
+    var document = EAction.getDocument();
+
     var value = this.getAdjustedPropertyValue(propertyTypeId);
     if (isNumber(index)) {
         value = value[index];
@@ -962,18 +1057,20 @@ PropertyEditorImpl.prototype.initNumberControls = function(objectName, propertyT
     var attributes = this.getPropertyAttributes(propertyTypeId);
 
     if (isNull(control)) {
-        control = new RMathLineEdit(this.geometryGroup);
-        if (attributes.isAngleType()) {
-            control.setAngle(true);
+        if (attributes.isScaleType() && !isNull(document)) {
+            control = new RMathComboBox(this.geometryGroup);
+            control.setScale(true, document.getUnit());
+        }
+        else {
+            control = new RMathLineEdit(this.geometryGroup);
+            if (attributes.isAngleType()) {
+                control.setAngle(true);
+            }
         }
-        // TODO: support scale in RMathLineEdit:
-//        if (attributes.isScaleType()) {
-//            control.setScale(true);
-//        }
         control.objectName = objectName;
     }
 
-    var newText;
+    var newText = "";
     if (attributes.isMixed()) {
         newText = PropertyEditor.varies;
     }
@@ -982,7 +1079,15 @@ PropertyEditorImpl.prototype.initNumberControls = function(objectName, propertyT
             if (attributes.isAngleType()) {
                 value = RMath.rad2deg(value);
             }
-            var document = EAction.getDocument();
+
+            var decimals = RSettings.getIntValue("PropertyEditor/Decimals", 8);
+            if (decimals<0) {
+                decimals = 0;
+            }
+            if (decimals>8) {
+                decimals = 8;
+            }
+
             if (RSettings.getBoolValue("PropertyEditor/FormatAsDecimal", false)!==true &&
                 !attributes.isAngleType() &&
                 !attributes.isAreaType() &&
@@ -993,7 +1098,7 @@ PropertyEditorImpl.prototype.initNumberControls = function(objectName, propertyT
                 (document.getLinearFormat()===RS.Fractional ||
                  document.getLinearFormat()===RS.FractionalStacked)*/) {
 
-                newText = RUnit.getLabel(value, document, 8);
+                newText = RUnit.getLabel(value, document, decimals);
 
                 if (document.getLinearFormat()===RS.Architectural ||
                     document.getLinearFormat()===RS.ArchitecturalStacked ||
@@ -1005,16 +1110,35 @@ PropertyEditorImpl.prototype.initNumberControls = function(objectName, propertyT
 
             }
             else {
-                newText = sprintf("%.6f", value);
+                newText = sprintf("%." + decimals + "f", value);
             }
         }
     }
 
-    if (control.text !== newText) {
-        control.text = newText;
-        control.setProperty("originalText", newText);
-        if (isFunction(control.clearError)) {
-            control.clearError();
+    if (isOfType(control, RMathLineEdit) || isOfType(control, QLineEdit)) {
+        if (control.text!==newText) {
+            control.text = newText;
+            control.setProperty("originalText", newText);
+            if (isFunction(control.clearError)) {
+                control.clearError();
+            }
+        }
+    }
+
+    if (isOfType(control, RMathComboBox)) {
+        if (control.currentText!==newText) {
+            // TODO: try to set scale value
+            // (note that 1" = 2" is the same as 6" = 1', so the conversion from scale notation to value is irreversible)
+//            if (!isNull(value)) {
+//                control.setValue(value);
+//            }
+//            else {
+                control.currentText = newText;
+//            }
+            control.setProperty("originalText", newText);
+            if (isFunction(control.lineEdit().clearError)) {
+                control.lineEdit().clearError();
+            }
         }
     }
 
@@ -1025,9 +1149,28 @@ PropertyEditorImpl.prototype.initNumberControls = function(objectName, propertyT
     }
 
     if (!onlyChanges) {
-        control.editingFinished.connect(
-                    new PropertyWatcher(this, control, propertyTypeId),
-                    'propertyChanged');
+        var lineEdit;
+        if (isOfType(control, RMathComboBox)) {
+            lineEdit = control.lineEdit();
+
+            // don't trigger change on text changes (makes editing impossible):
+//            control.editTextChanged.connect(
+//                        new PropertyWatcher(this, control, propertyTypeId),
+//                        'propertyChanged');
+        }
+        else {
+            lineEdit = control;
+        }
+
+        var pw = new PropertyWatcher(this, control, propertyTypeId);
+        lineEdit.editingFinished.connect(pw, pw.propertyChanged);
+    }
+
+    // move cursor to start if field is not being edited:
+    if (!control.focus) {
+        if (isOfType(control, RMathLineEdit)) {
+            control.cursorPosition = 0;
+        }
     }
 
     return new Array(control);
@@ -1070,7 +1213,7 @@ PropertyEditorImpl.prototype.initStringControls = function(objectName, propertyT
         clearButton = new QToolButton(this.geometryGroup);
         clearButton.objectName = objectName + "_clear";
         clearButton.iconSize = new QSize(12,12);
-        clearButton.icon = new QIcon(this.basePath + "/Clear.svg");
+        clearButton.icon = new QIcon(autoPath(this.basePath + "/Clear.svg"));
         clearButton.toolTip = qsTr("Use auto measurement");
         clearButton.clicked.connect(function() {
             control.text = "";
@@ -1079,9 +1222,13 @@ PropertyEditorImpl.prototype.initStringControls = function(objectName, propertyT
     }
 
     if (!onlyChanges) {
-        control.editingFinished.connect(
-                    new PropertyWatcher(this, control, propertyTypeId),
-                    'propertyChanged');
+        var pw = new PropertyWatcher(this, control, propertyTypeId);
+        control.editingFinished.connect(pw, pw.propertyChanged);
+    }
+
+    // move cursor to start if field is not being edited:
+    if (!control.focus) {
+        control.cursorPosition = 0;
     }
 
     if (isNull(clearButton)) {
@@ -1135,9 +1282,8 @@ PropertyEditorImpl.prototype.initBooleanControls = function(objectName, property
     }
 
     if (!onlyChanges) {
-        control['activated(int)'].connect(
-                    new PropertyWatcher(this, control, propertyTypeId),
-                    'propertyChanged');
+        var pw = new PropertyWatcher(this, control, propertyTypeId);
+        control['activated(int)'].connect(pw, pw.propertyChanged);
     }
 
     return new Array(control);
@@ -1149,7 +1295,7 @@ PropertyEditorImpl.prototype.initBooleanControls = function(objectName, property
  */
 PropertyEditorImpl.prototype.initChoiceControls = function(
     objectName, propertyTypeId, onlyChanges, control, choices, choicesData) {
-    
+
     var i;
 
     var value = this.getAdjustedPropertyValue(propertyTypeId);
@@ -1179,14 +1325,22 @@ PropertyEditorImpl.prototype.initChoiceControls = function(
         control.objectName = objectName;
 
         if (isNull(choicesData)/* && propertyTypeId.getId()!==REntity.PropertyLayer.getId()*/) {
-            control['activated(QString)'].connect(
-                        new PropertyWatcher(this, control, propertyTypeId),
-                        'propertyChanged');
+            var pw = new PropertyWatcher(this, control, propertyTypeId)
+            if (RSettings.getQtVersion() >= 0x060000) {
+                control.textActivated.connect(pw, pw.propertyChanged);
+            }
+            else {
+                control['activated(QString)'].connect(pw, pw.propertyChanged);
+            }
         }
         else {
-            control['activated(int)'].connect(
-                        new PropertyWatcher(this, control, propertyTypeId),
-                        'propertyChanged');
+            var pw = new PropertyWatcher(this, control, propertyTypeId);
+            if (RSettings.getQtVersion() >= 0x060000) {
+                control.activated.connect(pw, pw.propertyChanged);
+            }
+            else {
+                control['activated(int)'].connect(pw, pw.propertyChanged);
+            }
         }
     }
 
@@ -1199,6 +1353,27 @@ PropertyEditorImpl.prototype.initChoiceControls = function(
     else if (propertyTypeId.getId()===RTextEntity.PropertyVAlign.getId()) {
         WidgetFactory.initVAlignCombo(control);
     }
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimlunit.getId()) {
+        WidgetFactory.initDimlunitCombo(control);
+    }
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimtad.getId()) {
+        WidgetFactory.initDimtadCombo(control);
+    }
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimzin.getId()) {
+        WidgetFactory.initDimzinCombo(control);
+    }
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimdec.getId()) {
+        WidgetFactory.initDimdecCombo(control);
+    }
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimaunit.getId()) {
+        WidgetFactory.initDimaunitCombo(control);
+    }
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimazin.getId()) {
+        WidgetFactory.initDimazinCombo(control);
+    }
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimadec.getId()) {
+        WidgetFactory.initDimadecCombo(control);
+    }
     else if (propertyTypeId.getId()===RPolylineEntity.PropertyOrientation.getId()) {
         WidgetFactory.initOrientationCombo(control);
     }
@@ -1379,12 +1554,12 @@ PropertyEditorImpl.prototype.makeReadOnly = function(control) {
     }
 
     var p = control.palette;
-    if (isNull(control.oriPalette)) {
+    if (isNull(control.property("oriPalette"))) {
         control.setProperty("oriPalette", control.palette);
     }
 
-    p.setColor(QPalette.Active, QPalette.Text, control.oriPalette.color(QPalette.Disabled, QPalette.WindowText));
-    p.setColor(QPalette.Inactive, QPalette.Text, control.oriPalette.color(QPalette.Disabled, QPalette.WindowText));
+    p.setColor(QPalette.Active, QPalette.Text, control.property("oriPalette").color(QPalette.Disabled, QPalette.WindowText));
+    p.setColor(QPalette.Inactive, QPalette.Text, control.property("oriPalette").color(QPalette.Disabled, QPalette.WindowText));
 
 //    if (RSettings.hasDarkGuiBackground()) {
 //        p.setColor(QPalette.Base, new QColor("#0a0a0a"));
@@ -1408,12 +1583,12 @@ PropertyEditorImpl.prototype.makeReadWrite = function(control) {
     }
 
     var p = control.palette;
-    if (isNull(control.oriPalette)) {
+    if (isNull(control.property("oriPalette"))) {
         control.setProperty("oriPalette", control.palette);
     }
 
-    p.setColor(QPalette.Active, QPalette.Text, control.oriPalette.color(QPalette.Active, QPalette.WindowText));
-    p.setColor(QPalette.Inactive, QPalette.Text, control.oriPalette.color(QPalette.Inactive, QPalette.WindowText));
+    p.setColor(QPalette.Active, QPalette.Text, control.property("oriPalette").color(QPalette.Active, QPalette.WindowText));
+    p.setColor(QPalette.Inactive, QPalette.Text, control.property("oriPalette").color(QPalette.Inactive, QPalette.WindowText));
 //    //if (RSettings.hasDarkGuiBackground()) {
 //        p.setColor(QPalette.Base, control.oriBase);
 ////    }
@@ -1445,7 +1620,7 @@ PropertyEditorImpl.prototype.addCustomProperty = function() {
     var valueEdit = dialog.findChild("Value");
 
     if (!dialog.exec()) {
-        dialog.destroy();
+        destr(dialog);
         EAction.activateMainWindow();
         return;
     }
@@ -1457,7 +1632,7 @@ PropertyEditorImpl.prototype.addCustomProperty = function() {
     this.propertyChanged(new RPropertyTypeId(RSettings.getAppId(), name), value, this.getEntityTypeFilter());
     this.onlyChangesOverride = false;
 
-    dialog.destroy();
+    destr(dialog);
     EAction.activateMainWindow();
 };
 
@@ -1544,7 +1719,12 @@ PropertyEditor.init = function(basePath) {
     dock.objectName = "PropertyEditorDock";
     dock.setWidget(pe.widget);
     appWin.addPropertyListener(pe);
-    appWin.addLayerListener(pe.getRLayerListener());
+    if (RSettings.getQtVersion() >= 0x060000) {
+        appWin.addLayerListener(pe);
+    }
+    else {
+        appWin.addLayerListener(pe.getRLayerListener());
+    }
     appWin.addDockWidget(Qt.RightDockWidgetArea, dock);
     PropertyEditor.instance = pe;
 
