@@ -129,14 +129,28 @@ function isOfType(obj, type) {
  * Destroys the given object with C++ ownership.
  */
 function destr(obj) {
-    if (!RSettings.isQt(6)) {
-        obj.destroy();
-    }
-    else {
+    if (RSettings.getQtVersion() >= 0x060000) {
         // destroy does not work in Qt 6 / QJSEngine:
         // ("Invalid attempt to destroy() an indestructible object")
         obj.destr();
     }
+    else {
+        obj.destroy();
+    }
+}
+
+/**
+ * Get pointer from shared pointer object using data() (Qt5) or implicitly (Qt6).
+ */
+function getPtr(p) {
+    if (RSettings.getQtVersion() > 0x060000) {
+        return p;
+    }
+    else {
+        if (isFunction(p.data)) {
+            return p.data();
+        }
+    }
 }
 
 /**
@@ -1507,7 +1521,7 @@ function getWidgets(widget, ca, allowDuplicates) {
     var children = widget.children();
     for (var i = 0; i < children.length; ++i) {
         var child = children[i];
-        if (isDeleted(child)) {
+        if (isNull(child) || isDeleted(child)) {
             continue;
         }
         if (!isNull(child.objectName) && child.objectName !== "") {
@@ -3203,16 +3217,6 @@ function makeFlags() {
     }
 }
 
-function getQLocaleName(locale) {
-    if (isFunction(locale.name)) {
-        return locale.name();
-    }
-    else {
-        // QJSEngine does not allow "name" as function.
-        return locale.name2();
-    }
-}
-
 // fix QPlainTextEdit API for Qt 5:
 if (!isFunction(QPlainTextEdit.prototype.toPlainText)) {
     QPlainTextEdit.prototype.toPlainText = function() {
